/**
* Popup Checkbox List 1.0
*
* http://blog.andreaventuri.it/
*
* Copyright (c) 2012 Andrea Venturi
*
* Dual licensed under the MIT and GPL licenses:
* http://www.opensource.org/licenses/mit-license.php
* http://www.gnu.org/licenses/gpl.html
*/
(function( $ ) {

	var
		prefix = 'popchecklist',
		ul_class  = prefix+'_list',
		pop_class = prefix+'_popup',
		count = 1;

	/**************************************************************************/
	/****************** PRIVATE FUNCTIONS *************************************/
	/**************************************************************************/
	function resetContainer(obj){

		var uplist  = obj.data('uplist');
		var pop_id  = obj.data('pop_id');
		var options = obj.data('options');

		uplist.html('<li><a href="#" class="popup_open">'+options.label+'</a></li>');
		uplist.find('.popup_open').colorbox({inline:true, href: '#'+pop_id});
	}

	function showSelected(obj){

		var uplist = obj.data('uplist');
		var pop_id = obj.data('pop_id');

		// svuoto la lista
		resetContainer(obj);

		$('#'+pop_id+' input:checked').each(function(){

			// aggiungo un elemento alla lista per ogni checkbox selezionato
			var xid = $(this).attr('id');
			var text = $(this).siblings('label').text();

			uplist.append('<li><span><a href="#" class="close_tag" rel="'+xid+'"></a>'+text+'</span></li>');
		});
	}

	/**************************************************************************/
	/****************** PLUGIN DEFINITION *************************************/
	/**************************************************************************/
	$.fn.popchecklist = function(opts) {

		var uplist, options, pop_id;
		var obj = this;

		// unisco i parametri di default con quelli passati nella chiamata
		options = $.extend({}, $.fn.popchecklist.defaults, opts);

		// creo la lista che viene mostrata al posto dei checkbox
		uplist = $('<ul class="'+ul_class+'">');
		this.eq(0).before(uplist);

		// creo il contenitore che verr mostrato nella popup
		pop_id = prefix+'_'+count++;
		this.parents('form').append('<div class="'+prefix+'_hidden"><div class="'+pop_class+'" id="'+pop_id+'"></div></div>');
		$('#'+pop_id).prepend('<h2>'+options.title+'</h2>').append('<ul>');

		// sposto le checkbox e le relative label all'interno di una lista
		this.each(function(){

			var xid = $(this).attr('id');
			var lbl = $('label[for="'+xid+'"]');

			var li = $('<li>').append($(this)).append(lbl);
			$('#'+pop_id+' ul').append(li);
		});

		// salvo gli attributi dell'oggetto
		this.data('uplist', uplist);
		this.data('options', options);
		this.data('pop_id', pop_id);


		resetContainer(this);
		showSelected(this);

		// evento alla selezione/deselezione di un checkbox
		$('#'+pop_id+' input').click(function(){
			showSelected(obj);
		});

		// evento di eliminazione della opzione
		$('.close_tag').live('click', function(){

			// deseleziono il checkbox
			var checkbox_id = $(this).attr('rel');
			$('#'+checkbox_id).attr('checked',false);

			// elimino l'opzione dalla visualizzazione
			$(this).parents('li:eq(0)').remove();

			return false;
		});

		// questi due bind servono per evitare problemi di movimento della finestra
		// quando lo scroll del browser  tutto in fondo
		$(document).bind('cbox_open',    function(){ uplist.hide(); });
		$(document).bind('cbox_cleanup', function(){ uplist.show(); });

		return this;
	};

	$.fn.popchecklist.defaults = {
		title: 'Seleziona opzioni',
		label: 'Seleziona'
	};

})( jQuery );